objective

# XMLRésuméLibrary: User Guide

note | Element Reference | organization

## Name

objective — A person's employment goal

## Synopsis

### Content Model

    (para+)

### Attributes

Name | Type | Default
--- | --- | ---
id | ID | None
targets | CDATA | None

## Description

The `objective` element contains a statement of a person's goal. It commong specifies the industry or position in which a person would like to work.

### Parents

`objective` may be contained in these elements: `resume`

### Attributes

`id`

  A string used to uniquely identify an objective. The objective may then be referred to by this identifier.

## Examples

    <objective>
      <para>
        I seek a high-paying job in the golf playing industry. I would like at
        least 20 weeks of vacation per year.
      </para>
    </objective>

note | Element Reference | organization